# BoboCEP

[![CICD](https://github.com/r3w0p/bobocep/actions/workflows/cicd.yml/badge.svg)](
https://github.com/r3w0p/bobocep/actions/workflows/cicd.yml)
[![Security](https://github.com/r3w0p/bobocep/actions/workflows/security.yml/badge.svg)](
https://github.com/r3w0p/bobocep/actions/workflows/security.yml)
[![Code Repository](https://img.shields.io/badge/code-github-171515)](
https://github.com/r3w0p/bobocep/)
[![Documentation Status](https://readthedocs.org/projects/bobocep/badge/?version=latest)](
https://bobocep.readthedocs.io/)
[![Donate](https://img.shields.io/badge/donate-ko--fi-red?label=donate)](
https://ko-fi.com/r3w0p)
<br/>

[![License](https://img.shields.io/github/license/r3w0p/bobocep?color=blue&label=license)](
https://github.com/r3w0p/bobocep/blob/main/LICENSE/)
[![PyPI](https://img.shields.io/pypi/v/bobocep?color=blue&label=pypi)](
https://pypi.org/project/bobocep/)
[![Python](https://img.shields.io/pypi/pyversions/bobocep?color=blue&label=python)](
https://pypi.org/project/bobocep/)
[![Repo Size](https://img.shields.io/github/repo-size/r3w0p/bobocep?label=repo%20size)](
https://github.com/r3w0p/bobocep/pulse/)
<br/>

[![Issues](https://img.shields.io/github/issues/r3w0p/bobocep?label=issues)](
https://github.com/r3w0p/bobocep/issues/)
[![Coverage](https://img.shields.io/codeclimate/coverage/r3w0p/bobocep?label=coverage)](
https://codeclimate.com/github/r3w0p/bobocep/)
[![Maintainability](https://img.shields.io/codeclimate/maintainability/r3w0p/bobocep?label=maintainability)](
https://codeclimate.com/github/r3w0p/bobocep/)
[![License Scan](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fr3w0p%2Fbobocep.svg?type=shield)](
https://app.fossa.com/projects/git%2Bgithub.com%2Fr3w0p%2Fbobocep?ref=badge_shield)


`BoboCEP` is a [Complex Event Processing](https://en.wikipedia.org/wiki/Complex_event_processing) (CEP) engine
designed for [edge computing](https://en.wikipedia.org/wiki/Edge_computing) in
[Internet of Things](https://en.wikipedia.org/wiki/Internet_of_things) (IoT) systems
to facilitate inferential reasoning and decision-making on streaming data.
It provides [fault tolerance](https://en.wikipedia.org/wiki/Fault_tolerance) (FT) via the
[active replication](https://en.wikipedia.org/wiki/Replication_(computing)) of
partially-completed complex events across multiple instances of the software.


## License

`BoboCEP` is open source, as per the
[Open Source Definition](https://opensource.org/osd).
The code in this repository can be redistributed and/or modified under the terms of the 
[MIT License](https://github.com/r3w0p/bobocep/blob/main/LICENSE).
